import csv
from xml.etree.ElementTree import Element, SubElement, Comment, tostring, ElementTree
import datetime
#from ElementTree_pretty import prettify

def createTMX(source_file, output_file, srclang, targetlang, adminlang='en', segtype='phrase', datatype='PlainText', oEncoding='UTF-8', source_filter_delimiter=","):


    generated_on = str(datetime.datetime.now())

    root = Element('tmx')
    root.set('version', '1.4')

    header = SubElement(root, 'header')
    header.set('creationtool','')
    header.set('creationtoolversion', '')
    header.set('segtype', segtype)
    header.set('o-tmf', '')
    header.set('adminlang', adminlang)
    header.set('srclang', srclang)
    header.set('datatype', datatype)
    header.set('o-encoding', oEncoding)


    body = SubElement(root, 'body')

    with open(source_file) as f:
        reader = csv.DictReader(f, delimiter=source_filter_delimiter)
        for row in reader:
            print("row:", row)
            tu = SubElement(body, 'tu')
            
            tuv_src = SubElement(tu, 'tuv')
            tuv_src.set('xml:lang', srclang)
            seg_src = SubElement(tuv_src, 'seg')
            seg_src.text = row[srclang].strip()
            
            tuv_target = SubElement(tu, 'tuv')
            tuv_target.set('xml:lang', targetlang)
            seg_target = SubElement(tuv_target, 'seg')
            seg_target.text = row[targetlang].strip()

    ElementTree(root).write(output_file)



from setuptools import setup
from os.path import abspath, dirname, join

root_dir = abspath(dirname(__file__))

with open(join(root_dir, "README.md")) as f:
    long_description = f.read()

setup(
    name = 'csv-to-tmx',
    packages = ['csv_to_tmx'],
    package_dir = {'csv_to_tmx': 'csv_to_tmx'},
    version = '0.0.0',
    description = 'Creates a tmx file from a csv',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author = 'Victoria Mak',
    author_email = 'victoria@mak4lab.com',
    url = 'https://github.com/mak4lab/csv-to-tmx',
    download_url = 'https://github.com/mak4lab/csv-to-tmx/tarball/download',
    keywords = ['parallel corpus', 'machine translation', 'nmt', 'csv', 'tmx', 'translation memory', 'mt', 'sentence alignment'],
    classifiers = [
        'Development Status :: 3 - Alpha',
        "Programming Language :: Python :: 3",
        "License :: CC0 1.0 Universal (CC0 1.0) Public Domain Dedication",
        "Operating System :: OS Independent",
    ]
)
